==> sigaddons-7.0.2412.1.tgz: estoquepedidos/inherit/estoque/estoque_parametro_data.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv, fields
from openerp.tools.translate import _


class estoque_parametro(osv.Model):
    """
    Tabela de parametros de produtos
    """

    mensagem = 'Se marcado apenas usuarios com permissao "estoquepedido / manager" ' \
               'ou "prime/manager" para modulo prime, poderao voltar pedido de venda para esboco '
    _name = 'estoque.parametro'
    _inherit = 'estoque.parametro'

    _columns = {
        'estpar_esboco_somente_manager': fields.boolean('Voltar pedido de venda para esboco somente'
                                                        ' manager',
                                                        help=mensagem),
        'estpar_pedido_formato_impressao': fields.selection(
            [('1', 'A4'), ('2', 'A5'), ('3', 'Bobina'), ('4', 'Matricial')], string='Formato impressao',
            size=1),
        'estpar_pedido_tipo_codigo': fields.selection(
            [('I', 'Interno'), ('F', 'Fabricante'), ('B', 'Barras')], 'Codigo a imprimir', size=1),
        'estpar_comando_guilhotina': fields.char('Comando de corte do papel', size=10),
        'estpar_pedido_retrato_paisagem': fields.selection([('P', 'Paisagem'), ('R', 'Retrato')],
                                                           'Modo impressao', size=1),
        'estpar_so_admin_cancela_pedido': fields.boolean('So admin cancela pedido'),
        'estpar_email_mensagem_id': fields.many2one('financeiro.emails.cadastro', 'E-mail'),
        'estpar_item_em_uma_linha': fields.boolean(
            'Item em uma linha', help='Se marcado, ao imprimir pedido na impressora matricial a '
                                      'descricao do item nao sera impressa em mais de uma linha.'),
        'estpar_esboco_na_reserva': fields.boolean(
            'Reserva pedido em esboco', help='Se marcado, os pedidos em esboco serao considerados na reserva.'),
        'estpar_vias_pedido': fields.integer('Quant. vias para impressao'),
        'estpar_pedido_mensagem_padrao': fields.text(_('Mensagem padrao')),
    }

    _defaults = {
        'estpar_esboco_somente_manager': False,
        'estpar_pedido_tipo_codigo': lambda *a: 'I',
        'estpar_pedido_retrato_paisagem': lambda *a: 'R',
        'estpar_item_em_uma_linha': False,
        'estpar_vias_pedido': 1,
    }

==> sigaddons-7.0.2412.2.tgz: estoquepedidos/inherit/estoque/estoque_parametro_data.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2009 All Rights Reserved. Luiz Fernando Maciel Franca
#                    www.siginformatica.com.br luiz@siginformatica.com.br
#
##############################################################################

from openerp.osv import osv, fields
from openerp.tools.translate import _


class estoque_parametro(osv.Model):
    """
    Tabela de parametros de produtos
    """

    mensagem = 'Se marcado apenas usuarios com permissao "estoquepedido / manager" ' \
               'ou "prime/manager" para modulo prime, poderao voltar pedido de venda para esboco '
    _name = 'estoque.parametro'
    _inherit = 'estoque.parametro'

    _columns = {
        'estpar_esboco_somente_manager': fields.boolean('Voltar pedido de venda para esboco somente'
                                                        ' manager',
                                                        help=mensagem),
        'estpar_pedido_formato_impressao': fields.selection(
            [('1', 'A4'),
                       ('2', 'A5'),
                       ('3', 'Bobina'),
                       ('4', 'Matricial meia pagina'),
                       ('5', 'Matricial pagina inteira')], string='Formato impressao',
            size=1),
        'estpar_pedido_tipo_codigo': fields.selection(
            [('I', 'Interno'), ('F', 'Fabricante'), ('B', 'Barras')], 'Codigo a imprimir', size=1),
        'estpar_comando_guilhotina': fields.char('Comando de corte do papel', size=10),
        'estpar_pedido_retrato_paisagem': fields.selection([('P', 'Paisagem'), ('R', 'Retrato')],
                                                           'Modo impressao', size=1),
        'estpar_so_admin_cancela_pedido': fields.boolean('So admin cancela pedido'),
        'estpar_email_mensagem_id': fields.many2one('financeiro.emails.cadastro', 'E-mail'),
        'estpar_item_em_uma_linha': fields.boolean(
            'Item em uma linha', help='Se marcado, ao imprimir pedido na impressora matricial a '
                                      'descricao do item nao sera impressa em mais de uma linha.'),
        'estpar_esboco_na_reserva': fields.boolean(
            'Reserva pedido em esboco', help='Se marcado, os pedidos em esboco serao considerados na reserva.'),
        'estpar_vias_pedido': fields.integer('Quant. vias para impressao'),
        'estpar_pedido_mensagem_padrao': fields.text(_('Mensagem padrao')),
    }

    _defaults = {
        'estpar_esboco_somente_manager': False,
        'estpar_pedido_tipo_codigo': lambda *a: 'I',
        'estpar_pedido_retrato_paisagem': lambda *a: 'R',
        'estpar_item_em_uma_linha': False,
        'estpar_vias_pedido': 1,
    }
